@@ -4,8 +4,9 @@ from pydantic import BaseModel, Extra
 
 
 class Discriminator(BaseModel):
-    """When request bodies or response payloads may be one of a number of different schemas, a `discriminator` object
-    can be used to aid in serialization, deserialization, and validation.
+    """When request bodies or response payloads may be one of a number of
+    different schemas, a `discriminator` object can be used to aid in
+    serialization, deserialization, and validation.
 
     The discriminator is a specific object in a schema which is used to inform the consumer of the specification
     of an alternative schema based on the value associated with it.
@@ -19,9 +20,8 @@ class Discriminator(BaseModel):
     """
 
     mapping: Optional[Dict[str, str]] = None
-    """
-    An object to hold mappings between payload values and schema names or references.
-    """
+    """An object to hold mappings between payload values and schema names or
+    references."""
 
     class Config:
         extra = Extra.ignore
